@@ -1,23 +1,7 @@
-/***************************************************************************
- *   Copyright (C) 2017 by Nicolas Carion                                  *
- *   This file is part of Kdenlive. See www.kdenlive.org.                  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) version 3 or any later version accepted by the       *
- *   membership of KDE e.V. (or its successor approved  by the membership  *
- *   of KDE e.V.), which shall act as a proxy defined in Section 14 of     *
- *   version 3 of the license.                                             *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2017 Nicolas Carion
+    SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #ifndef KEYFRAMELISTMODEL_H
 #define KEYFRAMELISTMODEL_H
@@ -60,7 +44,7 @@ public:
     explicit KeyframeModel(std::weak_ptr<AssetParameterModel> model, const QModelIndex &index, std::weak_ptr<DocUndoStack> undo_stack,
                            QObject *parent = nullptr);
 
-    enum { TypeRole = Qt::UserRole + 1, PosRole, FrameRole, ValueRole, NormalizedValueRole };
+    enum { TypeRole = Qt::UserRole + 1, PosRole, FrameRole, ValueRole, NormalizedValueRole, SelectedRole, ActiveRole };
     friend class KeyframeModelList;
     friend class KeyframeWidget;
     friend class KeyframeImport;
@@ -93,7 +77,7 @@ protected:
 
 protected:
     /** @brief Same function but accumulates undo/redo */
-    bool removeKeyframe(GenTime pos, Fun &undo, Fun &redo, bool notify = true);
+    bool removeKeyframe(GenTime pos, Fun &undo, Fun &redo, bool notify = true, bool updateSelection = true);
 
 public:
     /** @brief moves a keyframe
@@ -104,7 +88,7 @@ public:
     bool moveKeyframe(int oldPos, int pos, bool logUndo);
     bool offsetKeyframes(int oldPos, int pos, bool logUndo);
     bool moveKeyframe(GenTime oldPos, GenTime pos, QVariant newVal, bool logUndo);
-    bool moveKeyframe(GenTime oldPos, GenTime pos, QVariant newVal, Fun &undo, Fun &redo);
+    bool moveKeyframe(GenTime oldPos, GenTime pos, QVariant newVal, Fun &undo, Fun &redo, bool updateView = true);
 
     /** @brief updates the value of a keyframe
        @param old is the position of the keyframe
@@ -163,6 +147,14 @@ public:
     QVariant updateInterpolated(const QVariant &interpValue, double val);
     /** @brief Return the real value from a normalized one */
     QVariant getNormalizedValue(double newVal) const;
+    /** @brief Set or add a keyframe to selection */
+    Q_INVOKABLE void setSelectedKeyframe(int ix, bool add);
+    void setSelectedKeyframes(QVector<int> selection);
+
+    Q_INVOKABLE int activeKeyframe() const;
+    Q_INVOKABLE void setActiveKeyframe(int ix);
+    int getIndexForPos(const GenTime pos) const;
+    GenTime getPosAtIndex(int ix) const;
 
     // Mandatory overloads
     Q_INVOKABLE QVariant data(const QModelIndex &index, int role) const override;
@@ -213,9 +205,11 @@ private:
     mutable QReadWriteLock m_lock;
 
     std::map<GenTime, std::pair<KeyframeType, QVariant>> m_keyframeList;
+    bool moveOneKeyframe(GenTime oldPos, GenTime pos, QVariant newVal, Fun &undo, Fun &redo, bool updateView = true);
 
 signals:
     void modelChanged();
+    void requestModelUpdate(const QModelIndex &, const QModelIndex &, const QVector<int>&);
 
 public:
     // this is to enable for range loops
