@@ -202,7 +202,7 @@ public:
     bool isLoading;
     void dockWidgetInit(QDockWidget* m_DockClipWidget);
     /** @brief Sets the document for the bin and initialize some stuff  */
-    void setDocument(KdenliveDoc *project, const QString &id = QString());
+    const QString setDocument(KdenliveDoc *project, const QString &id = QString());
     /** @brief Delete all project related data, to be called before setDocument  */
     void cleanDocument();
 
@@ -398,6 +398,7 @@ private slots:
     /** @brief Switch a tag on  a clip list
      */
     void editTags(QList <QString> allClips, const QString &tag, bool add);
+    void slotUpdatePalette();
 
 public slots:
     void slotRemoveInvalidClip(const QString &id, bool replace, const QString &errorMessage);
@@ -423,6 +424,7 @@ public slots:
     void slotOpenClip();
     void slotDuplicateClip();
     void slotLocateClip();
+    void showClipProperties(const std::shared_ptr<ProjectClip> &clip, bool forceRefresh = false);
     /** @brief Add extra data to a clip. */
     void slotAddClipExtraData(const QString &id, const QString &key, const QString &data = QString(), QUndoCommand *groupCommand = nullptr);
     void slotUpdateClipProperties(const QString &id, const QMap<QString, QString> &properties, bool refreshPropertiesPanel);
@@ -543,7 +545,6 @@ private:
     QFuture<void> m_audioThumbsThread;
     QAction *addAction(const QString &name, const QString &text, const QIcon &icon);
     void setupAddClipAction(QMenu *addClipMenu, ClipType::ProducerType type, const QString &name, const QString &text, const QIcon &icon);
-    void showClipProperties(const std::shared_ptr<ProjectClip> &clip, bool forceRefresh = false);
     /** @brief Get the QModelIndex value for an item in the Bin. */
     QModelIndex getIndexForId(const QString &id, bool folderWanted) const;
     std::shared_ptr<ProjectClip> getFirstSelectedClip();
@@ -562,6 +563,7 @@ signals:
     void refreshTimeCode();
     /** @brief Request display of effect stack for a Bin clip. */
     void requestShowEffectStack(const QString &clipName, std::shared_ptr<EffectStackModel>, QSize frameSize, bool showKeyframes);
+    void requestShowClipProperties(const std::shared_ptr<ProjectClip> &clip, bool forceRefresh = false);
     /** @brief Request that the given clip is displayed in the clip monitor */
     void requestClipShow(std::shared_ptr<ProjectClip>);
     void displayBinMessage(const QString &, KMessageWidget::MessageType);
@@ -582,6 +584,7 @@ signals:
     void deleteMarkers();
     /** @brief Selected all markers in clip properties dialog. */
     void selectMarkers();
+    void requestBinClose();
 };
 
 #endif
