@@ -71,6 +71,7 @@ ProjectClip::ProjectClip(const QString &id, const QIcon &thumb, const std::share
     : AbstractProjectItem(AbstractProjectItem::ClipItem, id, model)
     , ClipController(id, std::move(producer))
     , m_resetTimelineOccurences(false)
+    , m_audioCount(0)
 {
     m_markerModel = std::make_shared<MarkerListModel>(id, pCore->projectManager()->undoStack());
     if (producer->get_int("_placeholder") == 1) {
@@ -95,6 +96,11 @@ ProjectClip::ProjectClip(const QString &id, const QIcon &thumb, const std::share
     }
     // Make sure we have a hash for this clip
     hash();
+    m_boundaryTimer.setSingleShot(true);
+    m_boundaryTimer.setInterval(500);
+    if (m_hasLimitedDuration) {
+        connect(&m_boundaryTimer, &QTimer::timeout, this, &ProjectClip::refreshBounds);
+    }
     connect(m_markerModel.get(), &MarkerListModel::modelChanged, this, [&]() {
         setProducerProperty(QStringLiteral("kdenlive:markers"), m_markerModel->toJson());
     });
@@ -135,6 +141,7 @@ ProjectClip::ProjectClip(const QString &id, const QDomElement &description, cons
     : AbstractProjectItem(AbstractProjectItem::ClipItem, id, model)
     , ClipController(id)
     , m_resetTimelineOccurences(false)
+    , m_audioCount(0)
 {
     m_clipStatus = FileStatus::StatusWaiting;
     m_thumbnail = thumb;
@@ -154,6 +161,8 @@ ProjectClip::ProjectClip(const QString &id, const QDomElement &description, cons
     } else {
         m_name = i18n("Untitled");
     }
+    m_boundaryTimer.setSingleShot(true);
+    m_boundaryTimer.setInterval(500);
     connect(m_markerModel.get(), &MarkerListModel::modelChanged, this, [&]() { setProducerProperty(QStringLiteral("kdenlive:markers"), m_markerModel->toJson()); });
 }
 
@@ -545,6 +554,11 @@ bool ProjectClip::setProducer(std::shared_ptr<Mlt::Producer> producer)
     m_videoProducers.clear();
     m_timewarpProducers.clear();
     emit refreshPropertiesPanel();
+    if (m_hasLimitedDuration) {
+        connect(&m_boundaryTimer, &QTimer::timeout, this, &ProjectClip::refreshBounds);
+    } else {
+        disconnect(&m_boundaryTimer, &QTimer::timeout, this, &ProjectClip::refreshBounds);
+    }
     replaceInTimeline();
     updateTimelineClips({TimelineModel::IsProxyRole});
     bool generateProxy = false;
@@ -1259,6 +1273,11 @@ void ProjectClip::setProperties(const QMap<QString, QString> &properties, bool r
             } else {
                 reload = true;
                 refreshOnly = false;
+                // Restore original url
+                QString resource = getProducerProperty(QStringLiteral("kdenlive:originalurl"));
+                if (!resource.isEmpty()) {
+                    setProducerProperty(QStringLiteral("resource"), resource);
+                }
             }
         } else {
             // A proxy was requested, make sure to keep original url
@@ -1659,14 +1678,43 @@ void ProjectClip::registerTimelineClip(std::weak_ptr<TimelineModel> timeline, in
 {
     Q_ASSERT(m_registeredClips.count(clipId) == 0);
     Q_ASSERT(!timeline.expired());
+    if (m_hasAudio) {
+        if (auto ptr = timeline.lock()) {
+            if (ptr->getClipState(clipId) == PlaylistState::AudioOnly) {
+                m_audioCount++;
+            }
+        }
+    }
     m_registeredClips[clipId] = std::move(timeline);
-    setRefCount(uint(m_registeredClips.size()));
+    setRefCount(uint(m_registeredClips.size()), m_audioCount);
+    emit registeredClipChanged();
 }
 
-void ProjectClip::deregisterTimelineClip(int clipId)
+void ProjectClip::checkClipBounds()
+{
+    m_boundaryTimer.start();
+}
+
+void ProjectClip::refreshBounds()
+{
+    QVector <QPoint> boundaries;
+    for (const auto &registeredClip : m_registeredClips) {
+        if (auto ptr = registeredClip.second.lock()) {
+            QPoint point = ptr->getClipInDuration(registeredClip.first);
+            if (!boundaries.contains(point)) {
+                boundaries << point;
+            }
+        }
+    }
+    emit boundsChanged(boundaries);
+}
+
+void ProjectClip::deregisterTimelineClip(int clipId, bool audioClip)
 {
-    qDebug() << " ** * DEREGISTERING TIMELINE CLIP: " << clipId;
     Q_ASSERT(m_registeredClips.count(clipId) > 0);
+    if (m_hasAudio && audioClip) {
+        m_audioCount--;
+    }
     m_registeredClips.erase(clipId);
     if (m_videoProducers.count(clipId) > 0) {
         m_effectStack->removeService(m_videoProducers[clipId]);
@@ -1676,14 +1724,15 @@ void ProjectClip::deregisterTimelineClip(int clipId)
         m_effectStack->removeService(m_audioProducers[clipId]);
         m_audioProducers.erase(clipId);
     }
-    setRefCount(uint(m_registeredClips.size()));
+    setRefCount(uint(m_registeredClips.size()), m_audioCount);
+    emit registeredClipChanged();
 }
 
 QList<int> ProjectClip::timelineInstances() const
 {
     QList<int> ids;
-    for (const auto &m_registeredClip : m_registeredClips) {
-        ids.push_back(m_registeredClip.first);
+    for (const auto &registeredClip : m_registeredClips) {
+        ids.push_back(registeredClip.first);
     }
     return ids;
 }
