@@ -358,6 +358,10 @@ signals:
     void remapClip(int cid);
     /** @brief A monitor property changed, check if we need to reset */
     void monitorProfileUpdated();
+    /** @brief Color theme changed, process refresh */
+    void updatePalette();
+    /** @brief Emitted when a clip is resized (to handle clip monitor inserted zones) */
+    void clipInstanceResized(const QString &binId);
 };
 
 #endif
