@@ -1,22 +1,8 @@
-/***************************************************************************
- *                                                                         *
- *   Copyright (C) 2021 by Jean-Baptiste Mardelle (jb@kdenlive.org)        *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2021 Jean-Baptiste Mardelle <jb@kdenlive.org>
+
+SPDX-License-Identifier: GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+*/
 
 #include "scenesplittask.h"
 #include "bin/bin.h"
@@ -44,7 +30,6 @@
 SceneSplitTask::SceneSplitTask(const ObjectId &owner, double threshold, int markersCategory, bool addSubclips, int minDuration, QObject* object)
     : AbstractTask(owner, AbstractTask::ANALYSECLIPJOB, object)
     , m_jobDuration(0)
-    , m_threshold(threshold)
     , m_markersType(markersCategory)
     , m_subClips(addSubclips)
     , m_minInterval(minDuration)
@@ -54,6 +39,7 @@ SceneSplitTask::SceneSplitTask(const ObjectId &owner, double threshold, int mark
 
 void SceneSplitTask::start(QObject* object, bool force)
 {
+    Q_UNUSED(object)
     QPointer<QDialog> d = new QDialog;
     Ui::SceneCutDialog_UI view;
     view.setupUi(d);
@@ -190,7 +176,7 @@ void SceneSplitTask::run()
                 ix++;
             }
             QJsonDocument json(list);
-            QMetaObject::invokeMethod(m_object, "importJsonMarkers", Q_ARG(const QString&,QString(json.toJson())));
+            QMetaObject::invokeMethod(m_object, "importJsonMarkers", Q_ARG(QString,QString(json.toJson())));
         }
         if (m_subClips) {
             // Create zones
@@ -221,7 +207,7 @@ void SceneSplitTask::run()
             json.setArray(list);
             if (!json.isEmpty()) {
                 QString dataMap(json.toJson());
-                QMetaObject::invokeMethod(pCore->projectItemModel().get(), "loadSubClips", Q_ARG(const QString&,QString::number(m_owner.second)), Q_ARG(const QString&,dataMap));
+                QMetaObject::invokeMethod(pCore->projectItemModel().get(), "loadSubClips", Q_ARG(QString,QString::number(m_owner.second)), Q_ARG(QString,dataMap));
             }
         }
     } else {
@@ -249,7 +235,7 @@ void SceneSplitTask::processLogInfo()
         bool ok;
         QStringList output = buffer.split("[Parsed_showinfo");
         output.removeFirst();
-        for (const QString &o : output) {
+        for (const QString &o : qAsConst(output)) {
             if (o.contains(timeMarker)) {
                 double res = o.section(timeMarker, 1).section(QLatin1Char(' '), 0, 0).toDouble(&ok);
                 if (ok) {
